# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': '.'}

packages = \
['hifis_surveyval',
 'hifis_surveyval.core',
 'hifis_surveyval.files',
 'hifis_surveyval.models',
 'hifis_surveyval.models.mixins',
 'hifis_surveyval.plotting',
 'hifis_surveyval.printing']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.0',
 'matplotlib>=3.2.0',
 'numpy>=1.18.1',
 'pandas>=1.0.1',
 'pydantic>=1.8.1,<2.0.0',
 'python-dotenv>=0.17.0,<0.18.0',
 'pyyaml>=5.3.1',
 'schema>=0.7.4,<0.8.0',
 'tabulate>=0.8.9,<0.9.0']

entry_points = \
{'console_scripts': ['hifis-surveyval = hifis_surveyval.cli:cli']}

setup_kwargs = {
    'name': 'hifis-surveyval',
    'version': '1.0.0',
    'description': 'This project is used to develop analysis scripts for the HIFIS Software survey.',
    'long_description': '<!--\nhifis-surveyval\nFramework to help developing analysis scripts for the HIFIS Software survey.\n\nSPDX-FileCopyrightText: 2021 HIFIS Software <support@hifis.net>\n\nSPDX-License-Identifier: GPL-3.0-or-later\n\nThis program is free software: you can redistribute it and/or modify\nit under the terms of the GNU General Public License as published by\nthe Free Software Foundation, either version 3 of the License, or\n(at your option) any later version.\n\nThis program is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with this program. If not, see <http://www.gnu.org/licenses/>.\n-->\n\n# HIFIS-Surveyval\n\nThis project is used to develop analysis scripts for the HIFIS Software survey.\n\n## Table of Content\n\n* [Installation](#installation)\n* [Getting Started](#getting-started)\n* [Start Analysis from Command-Line-Interface](#start-analysis-from-command-line-interface)\n* [Contribute with Own Analysis Scripts](#contribute-with-own-analysis-scripts)\n* [Resources](#resources)\n* [Author Information](#author-information)\n* [Contributors](#contributors)\n* [License](#license)\n\n## Getting Started\n\nThe project\'s documentation contains a section to help you as a \n[user of the analysis scripts](#getting-for-users) \nto run the analysis scripts or as a \n[developer of the framework](#getting-started-for-developers)\nto set up the development environment.\n\n### Getting Started for Users\n\n#### Installation\n\nTo install the package locally, you can use \n[Pip](https://pip.pypa.io/en/stable/).\n\n```shell\npip install hifis-surveyval\n```\n\nAfter the installation, you can use the tool from the command line with \n`hifis-surveyval --help`.\n\n### Getting Started for Developers\n\n#### Installation\n\nTo install the package locally, you can use \n[Poetry](https://python-poetry.org/).\n\n#### Using Poetry\n\nIf you want to actively contribute changes to the project, you are required to\nalso install the development packages alongside the framework.\n\n```shell\ngit clone https://gitlab.hzdr.de/hifis/surveys/hifis-surveyval.git\ncd hifis-surveyval\npoetry install\n```\n\nAfter the installation, you can use the tool from the command line with \n`poetry run hifis-surveyval --help`\n\nPoetry installs some packages that are required for performing quality checks.\nUsually they are also performed via GitLab CI, but can also be executed locally.\n\nIt is common practice to run some checks locally before pushing them online.\nTherefore, execute below commands:\n```console\n$ # Order your imports\n$ isort -rc .\n$ make lint\n```\n\nThe following documentation references the pip installation.\nYou can use the same commands with a poetry installation, if you prefix your \ncommands with `poetry run COMMAND`.\n\n## Start Analysis from Command-Line-Interface\n\nThe survey analysis package is a program to be executed on the\nCommand-Line-Interface (CLI).\n\n### Quick Start Example: Run Analysis\n\nDue to sensible defaults of the project\'s configurations you need to have the \nanalysis scripts as well as metadata and data files in certain locations\nin order to run the survey analysis.\nPlease put your analysis scripts into a sub-folder called _scripts_.\nMake sure that the file _meta.yml_ is put into sub-folder _metadata_.\nFinally, copy the data-CSV-file for example from the \n[wiki page](https://gitlab.hzdr.de/hifis/survey-about-current-development-practice/-/wikis/home) \nof the associated GitLab project \n[Survey about current Development Practice](https://gitlab.hzdr.de/hifis/survey-about-current-development-practice)\ninto a central location like a _data_ sub-folder and tell the program the \npath to that data file.\n\nNow you can do the following to start the survey analysis from the CLI:\n\n```shell script\nhifis-surveyval analyze data/<data_file_name>.csv\n```\n\nThe output is then put into a sub-folder within the folder _output_ \nwhich is named after the stamp of the current date-time if not specified \ndifferently.\n\n**Caution:** \nDepending on the Operating System used an issue with the file \nencoding might occur.\nThere might be data-CSV-files around which are encoded with `UTF-8-BOM`\nwhich causes errors when read in on Windows OS.\nIn this case you need to change the encoding to `UTF-8` before running\nthe survey analysis.\n\n### Flags\n\nThe program accepts two flags:\n\n1. Help flag\n2. Verbosity flag\n\n#### Help flag\n\nCalling the program with the _help_-flag is the first thing to do\nwhen being encountered with this program.\nIt outputs a so-called _Usage_-message to the CLI:\n\n```shell script\n$ hifis-surveyval --help\n```\n\nPlease issue this command on the CLI and read the detailed \n_Usage_-message before continuing with reading the documentation\nof the _Usage_-message here.\n\n#### Verbosity flag\n\nThe _verbosity_-flag can be provided in order to specify the verbosity\nof the output to the CLI.\nThis flag is called `--verbose` or `-v` for short:\n\n```shell script\nhifis-surveyval --verbose <COMMAND>\n```\n```shell script\nhifis-surveyval -v <COMMAND>\n```\n\nThe verbosity of the output can be increased even more \nby duplicating the flag `--verbose` or `-v` up to two times:\n\n```shell script\nhifis-surveyval --verbose --verbose --verbose <COMMAND>\n```\n```shell script\nhifis-surveyval -vvv <COMMAND>\n```\n\n### Commands\n\nThere are three different commands implemented which come with its own set of\nflags and parameters:\n\n1. Command _version_\n2. Command _init_\n3. Command _analyze_\n\n#### Command _version_\n \nThe `version` command outputs the version number of this CLI-program like so:\n\n```shell script\nhifis-surveyval version\n```\n\n#### Command _init_\n\nBefore you start the analysis you may want to change the defaults of the\nconfiguration variables.\nIn order to do so, you can create a configuration file that is named \n_hifis-surveyval.yml_ by issuing the _init_ command:\n\n```shell script\nhifis-surveyval init\n```\n\nThis file contains the following information:\n\n```\nMETADATA: metadata/meta.yml\nOUTPUT_FOLDER: output\nOUTPUT_FORMAT: PNG\nSCRIPT_FOLDER: scripts\nSCRIPT_NAMES: []\n```\n\nFirst of all, each analysis needs metadata about the questions asked in the\nsurvey and answers that participants may give.\nThis metadata file is by default located in a folder called _metadata_\nand named _meta.yml_.\n\nSecond, you may specify the output folder which is named _output_ by default.\n\nThird, you may prefer a specific output format like _PDF_, _PNG_, _SVG_ or \n_SCREEN_.\nThe default value is _PNG_.\nNote: Be aware that other output formats like text or markdown files may be \ncreated, which depends largely upon the implementation of the analysis scripts.\n\nFourth, you may specify the folder which contains the analysis scripts, which\nis the _scripts_ folder by default.\n\nFinally, you may select a subset of the analysis scripts available as a list\nthat ought to be executed.\nThis list is empty by default, which means, all scripts are executed.\n\n#### Command _analyze_\n\nThe more interesting command is the `analyze` command\nwhich comes with a _data_-parameter.\nThe _data_-parameter can _not_ be omitted and need to be given explicitly\nin order to be able to start the analysis.\nThis is an example of how to do the analysis:\n\n```shell script\nhifis-surveyval analyze data/<data_file_name>.csv\n```\n\n## Contribute with Own Analysis Scripts\n\n### Essential Requirements for Developing Own Analysis Scripts\n\nAs you might have read in the previous sections the actual analysis scripts \nreside in a specific folder called `scripts`.\nAll scripts in that folder will be automatically discovered by the package \n`hifis-surveyval` when running the analysis.\nIn order that the program recognizes the scripts in that folder as\nanalysis scripts they need to fulfill the following two criteria:\n\n1. The filename need to end on `.py`.\n2. The file need to contain a function called `run` without any parameters.\n\n```python\n"""\nA dummy script for testing the function dispatch\n\n.. currentmodule:: hifis_surveyval.scripts.dummy\n.. moduleauthor:: HIFIS Software <software@hifis.net>\n"""\n\ndef run():\n    print("Example Script")\n```\n\nIf both requirements are satisfied the program will execute the `run`-functions\nof the analysis scripts in an arbitrary order.\n\n### File-System Structure of the Core Component\n\n```shell script\n$ tree hifis_surveyval/\nhifis_surveyval/\n├── answer.py\n├── cli.py\n├── core\n│   ├── environment.py\n│   ├── __init__.py\n│   └── settings.py\n├── data.py\n├── dispatch.py\n├── globals.py\n├── __init__.py\n├── plot.py\n├── question.py\n└── util.py\n```\n\n## Resources\n\nBelow are some handy resource links:\n\n* [Project Documentation](TODO)\n* [Click](https://click.palletsprojects.com/en/7.x) is a Python package for creating beautiful command line interfaces in a composable way with as little code as necessary.\n* [Sphinx](http://www.sphinx-doc.org/en/master/) is a tool that makes it easy to create intelligent and beautiful documentation, written by Geog Brandl and licnsed under the BSD license.\n* [pytest](https://docs.pytest.org/en/latest/) helps you write better programs.\n* [GNU Make](https://www.gnu.org/software/make/) is a tool which controls the generation of executables and other non-source files of a program from the program\'s source files.\n\n## Author Information\n\n_HIFIS-Surveyval_ was created by \n[HIFIS Software Services](https://software.hifis.net/).\n\n## Contributors\n\nWe would like to thank and give credits to the following contributors of this\nproject:\n\n* Be the first to be named here!\n\n## License\n\nCopyright © 2021 HIFIS Software <support@hifis.net>\n\nThis work is licensed under the following license(s):\n* Everything else is licensed under [GPL-3.0-or-later](LICENSES/GPL-3.0-or-later.txt)\n\nPlease see the individual files for more accurate information.\n\n> **Hint:** We provided the copyright and license information in accordance to the [REUSE Specification 3.0](https://reuse.software/spec/).',
    'author': 'HIFIS Software',
    'author_email': 'software@hifis.net',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://gitlab.hzdr.de/hifis/surveys/hifis-surveyval',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<3.10',
}


setup(**setup_kwargs)
